@@ -1,36 +1,18 @@
 /*
-   This file is part of the KDE libraries
-
-   Copyright (c) 2008 Michael Leupold <lemma@confuego.org>
-
-   This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
-   License as published by the Free Software Foundation; either
-   version 2 of the License, or (at your option) any later version.
-
-   This library is distributed in the hope that it will be useful,
-   but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-
-   You should have received a copy of the GNU Library General Public License
-   along with this library; see the file COPYING.LIB.  If not, write to
-   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02110-1301, USA.
+    This file is part of the KDE libraries
+    SPDX-FileCopyrightText: 2008 Michael Leupold <lemma@confuego.org>
 
+    SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
-#include <QTextStream>
-#include <QTimer>
-#include <QThread>
-#include <KAboutData>
-#include <QtWidgets/QApplication>
-#include <QtTest/QTest>
-#include <KLocalizedString>
-#include <kwallet.h>
-
 #include "kwalletmany.h"
 
+#include <QTextStream>
+#include <QThread>
+#include <QApplication>
+#include <QTest>
+#include <kwallet.h>
+
 #define NUMWALLETS 10
 
 using namespace KWallet;
@@ -54,7 +36,8 @@ void KWalletMany::init()
 
 void KWalletMany::walletOpened(bool open)
 {
-    _out << "Got async wallet: " << (open) << endl;
+    _out << "Got async wallet: " << (open) << '\n';
+    _out.flush();
     --_pending;
 }
 
@@ -63,13 +46,14 @@ void KWalletMany::openWallet()
     // open plenty of wallets in synchronous and asynchronous mode
     for (int i = 0; i < NUMWALLETS; ++i) {
         // request asynchronous wallet
-        _out << "About to ask for wallet async" << endl;
+        _out << "About to ask for wallet async" << '\n';
         Wallet *wallet;
         wallet = Wallet::openWallet(Wallet::NetworkWallet(), 0, Wallet::Asynchronous);
         QVERIFY(wallet != nullptr);
         connect(wallet, SIGNAL(walletOpened(bool)), SLOT(walletOpened(bool)));
         _wallets.append(wallet);
     }
+    _out.flush();
 
     // wait for 30s to receive the wallet opened replies from kwalletd
     QTRY_VERIFY_WITH_TIMEOUT(_pending == 0, 30000);
